@@ -4,7 +4,9 @@ from pathlib import Path
 
 from pyspark.sql import SparkSession
 
-from spark_pipeline_framework_testing.test_runner import SparkPipelineFrameworkTestRunner
+from spark_pipeline_framework_testing.test_runner import (
+    SparkPipelineFrameworkTestRunner,
+)
 
 
 def cleanup_files(data_dir: Path) -> None:
@@ -19,7 +21,7 @@ def cleanup_files(data_dir: Path) -> None:
 
 
 def test_folder(spark_session: SparkSession) -> None:
-    data_dir: Path = Path(__file__).parent.joinpath('./')
+    data_dir: Path = Path(__file__).parent.joinpath("./")
 
     SparkPipelineFrameworkTestRunner.run_tests(
         spark_session=spark_session, folder_path=data_dir
